@@ -1,7 +1,9 @@
 package Mojo::Reactor::POE;
+
+use POE; # Loaded early to avoid event loop confusion
+
 use Mojo::Base 'Mojo::Reactor';
 
-use POE;
 use Mojo::Reactor::Poll;
 use Mojo::Util qw(md5_sum steady_time);
 use Scalar::Util 'weaken';
@@ -9,7 +11,7 @@ use Scalar::Util 'weaken';
 use constant { POE_IO_READ => 0, POE_IO_WRITE => 1 };
 use constant DEBUG => $ENV{MOJO_REACTOR_POE_DEBUG} || 0;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 my $POE;
 
@@ -110,8 +112,10 @@ sub _timer {
 		= {cb => $cb, after => $after, time => steady_time + $after};
 	$timer->{recurring} = $after if $recurring;
 	
-	my $is_recurring = $recurring ? ' (recurring)' : '';
-	warn "-- Set timer $id after $after seconds$is_recurring\n" if DEBUG;
+	if (DEBUG) {
+		my $is_recurring = $recurring ? ' (recurring)' : '';
+		warn "-- Set timer $id after $after seconds$is_recurring\n";
+	}
 	
 	$self->_send_set_timer($id);
 	
@@ -371,6 +375,7 @@ Mojo::Reactor::POE - POE backend for Mojo::Reactor
 
   # Or in an application using Mojo::IOLoop
   BEGIN { $ENV{MOJO_REACTOR} = 'Mojo::Reactor::POE' }
+  use POE qw(Loop::IO_Poll);
   use Mojo::IOLoop;
 
 =head1 DESCRIPTION
@@ -381,6 +386,12 @@ L<Mojo::Reactor::Poll>. To set it as the default backend for L<Mojo::Reactor>,
 set the C<MOJO_REACTOR> environment variable to C<Mojo::Reactor::POE>. This
 must be set before L<Mojo::IOLoop> is loaded.
 
+Note that if you load multiple potential event loops for L<POE> it will fail.
+This includes L<IO::Poll> and L<Mojo::IOLoop> (loaded by L<Mojolicious>) if the
+appropriate L<POE::Loop> modules are installed. To avoid this, load L<POE>
+before any L<Mojolicious> module, or specify the L<POE> event loop explicitly.
+See L<POE::Kernel/"Using POE with Other Event Loops">.
+
 =head1 EVENTS
 
 L<Mojo::Reactor::POE> inherits all events from L<Mojo::Reactor>.
